import numpy as np
from pyTurbulence.spectrum import energy_spectrum

def test_energy_spectrum_passot_pouquet():
    k = np.linspace(0,1024,1024)
    TKE = 0.5
    urms = np.sqrt(2. * TKE / 3.)
    k0 = 4.0
    spectrum = energy_spectrum("PassotPouquet", k, urms, k0)
    TKE_spectrum = np.trapz(spectrum, k)
    idxMax = np.argmax(spectrum)
    k0_spectrum = k[idxMax]
    assert np.isclose(k0_spectrum, k0,rtol=1e-2), "Test failed: PassotPouquet spectrum does not match expected k0"
    assert np.isclose(TKE_spectrum, TKE, rtol=1e-2), "Test failed: PassotPouquet spectrum does not conserve TKE"

def test_energy_spectrum_constant():
    k = np.linspace(0,1024,1024)
    TKE = 0.5
    k0 = 4.0
    spectrum = energy_spectrum("Constant", k, TKE, k0)
    TKE_spectrum = np.trapz(spectrum, k)
    idxMax = np.argmax(spectrum)
    k0_spectrum = k[idxMax]
    assert np.isclose(k0_spectrum, k0,1e-2), "Test failed: Constant spectrum does not match expected k0"

test_energy_spectrum_passot_pouquet()
test_energy_spectrum_constant()